@@ -15,11 +15,14 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.data_lake import AzureDataLakeHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class ADLSDeleteOperator(BaseOperator):
     """
@@ -57,7 +60,7 @@ class ADLSDeleteOperator(BaseOperator):
         self.ignore_not_found = ignore_not_found
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
-    def execute(self, context: dict) -> Any:
+    def execute(self, context: "Context") -> Any:
         hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
         return hook.remove(path=self.path, recursive=self.recursive, ignore_not_found=self.ignore_not_found)
 
@@ -96,7 +99,7 @@ class ADLSListOperator(BaseOperator):
         self.path = path
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
-    def execute(self, context: dict) -> list:
+    def execute(self, context: "Context") -> list:
         hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
         self.log.info('Getting list of ADLS files in path: %s', self.path)
         return hook.list(path=self.path)
