@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-from typing import Any, List, Optional
+from typing import TYPE_CHECKING, Any, List, Optional, Sequence
 
 from azure.batch import models as batch_models
 
@@ -24,6 +24,9 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.batch import AzureBatchHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class AzureBatchOperator(BaseOperator):
     """
@@ -121,7 +124,7 @@ class AzureBatchOperator(BaseOperator):
     :type should_delete_pool: bool
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'batch_pool_id',
         'batch_pool_vm_size',
         'batch_job_id',
@@ -266,7 +269,7 @@ class AzureBatchOperator(BaseOperator):
                 "Some required parameters are missing.Please you must set all the required parameters. "
             )
 
-    def execute(self, context: dict) -> None:
+    def execute(self, context: "Context") -> None:
         self._check_inputs()
         self.hook.connection.config.retry_policy = self.batch_max_retries
 
