@@ -15,15 +15,48 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence
 
-from airflow.models import BaseOperator
+from airflow.hooks.base import BaseHook
+from airflow.models import BaseOperator, BaseOperatorLink, TaskInstance
 from airflow.providers.microsoft.azure.hooks.data_factory import (
     AzureDataFactoryHook,
     AzureDataFactoryPipelineRunException,
     AzureDataFactoryPipelineRunStatus,
 )
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
+
+class AzureDataFactoryPipelineRunLink(BaseOperatorLink):
+    """Constructs a link to monitor a pipeline run in Azure Data Factory."""
+
+    name = "Monitor Pipeline Run"
+
+    def get_link(self, operator, dttm):
+        ti = TaskInstance(task=operator, execution_date=dttm)
+        run_id = ti.xcom_pull(task_ids=operator.task_id, key="run_id")
+
+        conn = BaseHook.get_connection(operator.azure_data_factory_conn_id)
+        subscription_id = conn.extra_dejson["extra__azure_data_factory__subscriptionId"]
+        # Both Resource Group Name and Factory Name can either be declared in the Azure Data Factory
+        # connection or passed directly to the operator.
+        resource_group_name = operator.resource_group_name or conn.extra_dejson.get(
+            "extra__azure_data_factory__resource_group_name"
+        )
+        factory_name = operator.factory_name or conn.extra_dejson.get(
+            "extra__azure_data_factory__factory_name"
+        )
+        url = (
+            f"https://adf.azure.com/en-us/monitoring/pipelineruns/{run_id}"
+            f"?factory=/subscriptions/{subscription_id}/"
+            f"resourceGroups/{resource_group_name}/providers/Microsoft.DataFactory/"
+            f"factories/{factory_name}"
+        )
+
+        return url
+
 
 class AzureDataFactoryRunPipelineOperator(BaseOperator):
     """
@@ -73,7 +106,7 @@ class AzureDataFactoryRunPipelineOperator(BaseOperator):
     :type check_interval: int
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         "azure_data_factory_conn_id",
         "resource_group_name",
         "factory_name",
@@ -85,6 +118,8 @@ class AzureDataFactoryRunPipelineOperator(BaseOperator):
 
     ui_color = "#0678d4"
 
+    operator_extra_links = (AzureDataFactoryPipelineRunLink(),)
+
     def __init__(
         self,
         *,
@@ -98,8 +133,8 @@ class AzureDataFactoryRunPipelineOperator(BaseOperator):
         start_activity_name: Optional[str] = None,
         start_from_failure: Optional[bool] = None,
         parameters: Optional[Dict[str, Any]] = None,
-        timeout: Optional[int] = 60 * 60 * 24 * 7,
-        check_interval: Optional[int] = 60,
+        timeout: int = 60 * 60 * 24 * 7,
+        check_interval: int = 60,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -116,7 +151,7 @@ class AzureDataFactoryRunPipelineOperator(BaseOperator):
         self.timeout = timeout
         self.check_interval = check_interval
 
-    def execute(self, context: Dict) -> None:
+    def execute(self, context: "Context") -> None:
         self.hook = AzureDataFactoryHook(azure_data_factory_conn_id=self.azure_data_factory_conn_id)
         self.log.info(f"Executing the {self.pipeline_name} pipeline.")
         response = self.hook.run_pipeline(
