@@ -16,11 +16,14 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-from typing import Optional
+from typing import TYPE_CHECKING, Optional, Sequence
 
 from airflow.providers.microsoft.azure.hooks.wasb import WasbHook
 from airflow.sensors.base import BaseSensorOperator
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class WasbBlobSensor(BaseSensorOperator):
     """
@@ -37,7 +40,7 @@ class WasbBlobSensor(BaseSensorOperator):
     :type check_options: dict
     """
 
-    template_fields = ('container_name', 'blob_name')
+    template_fields: Sequence[str] = ('container_name', 'blob_name')
 
     def __init__(
         self,
@@ -56,7 +59,7 @@ class WasbBlobSensor(BaseSensorOperator):
         self.blob_name = blob_name
         self.check_options = check_options
 
-    def poke(self, context: dict):
+    def poke(self, context: "Context"):
         self.log.info('Poking for blob: %s\n in wasb://%s', self.blob_name, self.container_name)
         hook = WasbHook(wasb_conn_id=self.wasb_conn_id)
         return hook.check_for_blob(self.container_name, self.blob_name, **self.check_options)
@@ -77,7 +80,7 @@ class WasbPrefixSensor(BaseSensorOperator):
     :type check_options: dict
     """
 
-    template_fields = ('container_name', 'prefix')
+    template_fields: Sequence[str] = ('container_name', 'prefix')
 
     def __init__(
         self,
@@ -96,7 +99,7 @@ class WasbPrefixSensor(BaseSensorOperator):
         self.prefix = prefix
         self.check_options = check_options
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: "Context") -> bool:
         self.log.info('Poking for prefix: %s in wasb://%s', self.prefix, self.container_name)
         hook = WasbHook(wasb_conn_id=self.wasb_conn_id)
         return hook.check_for_prefix(self.container_name, self.prefix, **self.check_options)
