@@ -15,12 +15,15 @@
 # specific language governing permissions and limitations
 # under the License.
 import warnings
-from typing import Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.data_lake import AzureDataLakeHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class LocalFilesystemToADLSOperator(BaseOperator):
     """
@@ -58,7 +61,7 @@ class LocalFilesystemToADLSOperator(BaseOperator):
     :type azure_data_lake_conn_id: str
     """
 
-    template_fields = ("local_path", "remote_path")
+    template_fields: Sequence[str] = ("local_path", "remote_path")
     ui_color = '#e4f0e8'
 
     def __init__(
@@ -84,7 +87,7 @@ class LocalFilesystemToADLSOperator(BaseOperator):
         self.extra_upload_options = extra_upload_options
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
-    def execute(self, context: dict) -> None:
+    def execute(self, context: "Context") -> None:
         if '**' in self.local_path:
             raise AirflowException("Recursive glob patterns using `**` are not supported")
         if not self.extra_upload_options:
